@@ -59,7 +59,7 @@ def json_force_parameter_type_method(funct):
                 kwargs[p] = parameters[p].annotation(kwargs[p])
                 if pi < len(args):
                     args.insert(pi, args.pop(pi).into(parameters[p].annotation))
-        return funct(self, *args, **kwargs)
+        return funct(self_or_cls, *args, **kwargs)
     return decorated
 
 
